# Table of Contents

- [setting-up-odata-integration-with-business-intelligence-tools](<./setting-up-odata-integration-with-business-intelligence-tools.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Setting Up the OData Integration with Business Intelligence Tools](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools.md>)
  - [Video Tutorial for Microsoft Power BI and Tableau](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools/Video-Tutorial-for-Microsoft-Power-BI-and-Tableau.md>)
  - [Microsoft Power BI](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools/Microsoft-Power-BI.md>)
  - [Changing Authentication Credentials for an OData Feed](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools/Changing-Authentication-Credentials-for-an-OData-Feed.md>)
  - [Using Dataflows](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools/Using-Dataflows.md>)
  - [Tableau](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools/Tableau.md>)
  - [SAP Tools](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools/SAP-Tools.md>)
  - [Was this page helpful?](<./Setting-Up-the-OData-Integration-with-Business-Intelligence-Tools/Was-this-page-helpful.md>)
